import sys
from collections import Counter
from operator import itemgetter
from random import shuffle
from string import punctuation

PUNCTUATION = set(punctuation)

def tokenize(document):
    for token in document.split():
        if len(token) == 1:
            yield token
        else:
            chunk = token[0]
            for char0, char1 in zip(token[:-1], token[1:]):
                if (char0 in PUNCTUATION) == (char1 in PUNCTUATION):
                    chunk += char1
                else:
                    yield chunk
                    chunk = char1
            if chunk:
                yield chunk


def load_imdb():
    with open('../data/imdb/imdb_unsup.txt', 'r') as f:
        return [list(tokenize(line.lower())) for line in f]


def get_vocab(documents, min_count=50):
    word_counts = Counter(token for document in documents for token in document)
    word_list = sorted(((word, count) for word, count in word_counts.items() if count >= min_count))
    return {word: index for index, (word, _) in enumerate(word_list)}


def load_rt(train_prop=0.9):
    with open('../data/rt-polarity/rt-polarity.neg.utf8', 'r') as f:
        neg = [list(tokenize(line)) for line in f]
        shuffle(neg)
        n_train = int(train_prop*len(neg))
        neg_train, neg_test = neg[:n_train], neg[n_train:]
    with open('../data/rt-polarity/rt-polarity.pos.utf8', 'r') as f:
        pos = [list(tokenize(line)) for line in f]
        shuffle(pos)
        n_train = int(train_prop*len(pos))
        pos_train, pos_test = pos[:n_train], pos[n_train:]

    return ([0]*len(neg_train)+[1]*len(pos_train), neg_train+pos_train, [0]*len(neg_test)+[1]*len(pos_test), neg_test+pos_test)
